#!/bin/bash

PROJECT="${1}"
OUT_DIR="${2}"

if [ -z "${PROJECT}" -o -z "${OUT_DIR}" ] ; then
	echo "Usage: $0 <course_dir> <output_dir> [instructor_base_uri] [instructor_base_host] [student_base_uri] [student_base_host]"
	printf "\n\n\tbase_uri\t - URI to use when building urls\n"
	printf "\tbase_host\t - host to use when building urls. useful for testing: https://localhost:8000"
	exit 1
fi

if [ ! -d "${OUT_DIR}" ] ; then
	mkdir "${OUT_DIR}" || exit 1
fi

if [ ! -z "${5}" ]; then
	STUDENT_BASE_URL=", base_url='${5}'"
else
	STUDENT_BASE_URL=""
fi

if [ ! -z "${6}" ] ; then
	STUDENT_BASE_HOST=", base_host='${6}'"
else
	STUDENT_BASE_HOST=""
fi

if [ ! -z "${3}" ]; then
	INSTRUCTOR_BASE_URL=", base_url='${3}'"
else
	INSTRUCTOR_BASE_URL=""
fi

if [ ! -z "${4}" ] ; then
	INSTRUCTOR_BASE_HOST=", base_host='${4}'"
else
	INSTRUCTOR_BASE_HOST=""
fi

#clear artifacts from previous builds

test -e "${OUT_DIR}/${PROJECT}_instructor" && rm -r ${OUT_DIR}/*
test -e "${OUT_DIR}/${PROJECT}_student" && rm -r ${OUT_DIR}/*


if [ "${BUILD_INSTRUCTOR}" = "True" ]; then
	#Copy latest course into instructor directory
	cp -r "${PROJECT}" "${OUT_DIR}/${PROJECT}_instructor"

	python3 -c "from process_course import course; course('${OUT_DIR}/${PROJECT}_instructor'${INSTRUCTOR_BASE_URL}${INSTRUCTOR_BASE_HOST})"
fi

if [ "${BUILD_STUDENT}" = "True" ]; then
	#refresh project dir for student version
	cp -r "${PROJECT}" "${OUT_DIR}/${PROJECT}_student"

	python3 -c "from process_course import course; course('${OUT_DIR}/${PROJECT}_student', student_mode=True${STUDENT_BASE_URL}${STUDENT_BASE_HOST})"
fi

chmod -R 777 ${OUT_DIR}/*  && ls -al ${OUT_DIR}
